# -*- coding: utf-8 -*-
"""The utils functions of the arthub_login_window."""

# Import built-in modules
import os

# Import third-party modules
from platformdirs import user_cache_dir


def current_path():
    return os.path.dirname(__file__)


def get_resource_file(file_name):
    root = current_path()
    return os.path.join(root, "resources", file_name)


def read_file(file_path):
    with open(file_path, "r") as file_obj:
        return file_obj.read()


def write_file(file_path, data):
    with open(file_path, "w") as file_obj:
        file_obj.write(data)


def get_login_account():
    account_file = get_account_cache_file()
    if os.path.exists(account_file):
        return read_file(account_file)


def save_login_account(account, cache_file=None):
    account_file = cache_file or get_account_cache_file()
    write_file(account_file, account)


def get_account_cache_file():
    root = user_cache_dir(appauthor="arthub", opinion=False)
    try:
        os.makedirs(root)
    # Ingoing when try create folder failed.
    except (IOError, WindowsError):
        pass
    return os.path.join(root, "arthub_account")



# Import third-party modules
import pytest

# Import local modules
from arthub_login_widgets.core import LoginWindow


class FakeAPI:
    def __init__(self, mocker, login_status=True):
        self.login_status = login_status
        self.mocker = mocker

    def login(self, account, password):
        return self.mocker.MagicMock(
            is_succeeded=self.mocker.MagicMock(return_value=self.login_status),
            error_message=self.mocker.MagicMock(return_value="login failed."),
        )


class TestLoginWindow:
    @pytest.fixture(autouse=True)
    def setup(self, mocker, qtbot):
        self.widget = LoginWindow(api=FakeAPI(mocker))
        qtbot.addWidget(self.widget)

    def test_show_widget(self):
        self.widget.line_edit_password.setText("xxxx")
        assert self.widget.line_edit_password.text() == "xxxx"

    def test_run_callback(self):
        def _custom_callback(api):
            print("run custom callback...")
            api._custom_callback = "custom callback"
            assert True

        self.widget.line_edit_account.setText("abc")
        self.widget.line_edit_password.setText("abc")
        self.widget.set_callback(_custom_callback)
        self.widget.login()
        assert self.widget._custom_callback == "custom callback"

    def test_login_failed(self, mocker):
        widget = LoginWindow(FakeAPI(mocker=mocker, login_status=False))
        widget.line_edit_account.setText("abc")
        widget.line_edit_password.setText("abc")

        widget.login()
        assert widget.label_prompt.text() == "login failed."



"""Describe our module distribution to Distutils."""

# Import future modules
from __future__ import absolute_import
from __future__ import division
from __future__ import print_function

# Import third-party modules
from setuptools import find_packages
from setuptools import setup
import os
from codecs import open

about = {}
here = os.path.abspath(os.path.dirname(__file__))
with open(os.path.join(here, "arthub_login_widgets", "__version__.py"), "r", "utf-8") as f:
    exec(f.read(), about)

setup(
    name="arthub_login_widgets",
    version=about["__version__"],
    author="Joey Ding",
    author_email="joeyding@tencent.com",
    url="https://git.woa.com/lightbox/internal/arthub_login_widgets",
    package_dir={"": "."},
    packages=find_packages("."),
    description="A Qt Widget for login ArtHub.",
    entry_points={},
    include_package_data=True,
    package_data={"": ["*.png", "*.qss"]},
    classifiers=[
        "Programming Language :: Python",
        "Programming Language :: Python :: 2",
        "Programming Language :: Python :: 3",
    ],
    install_requires=[
        "arthub_api==1.4.1",
        "platformdirs==2.0.2",
        "qtpy"
    ]
)
